|logo1|

.. |logo1| image:: https://freediscovery.github.io/static/freediscovery-full-logo-v2.png
    :scale: 80 %

.. image:: https://img.shields.io/pypi/v/freediscovery.svg
    :target: https://pypi.python.org/pypi/freediscovery

.. image:: https://anaconda.org/conda-forge/freediscovery/badges/version.svg
  :target: https://github.com/conda-forge/freediscovery-feedstock

.. image:: https://travis-ci.org/FreeDiscovery/FreeDiscovery.svg?branch=master
    :target: https://travis-ci.org/FreeDiscovery/FreeDiscovery

.. image:: https://ci.appveyor.com/api/projects/status/w5kjscmqlrlehp5t/branch/master?svg=true
    :target: https://ci.appveyor.com/project/FreeDiscovery/freediscovery/branch/master

.. image:: https://codecov.io/gh/FreeDiscovery/FreeDiscovery/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/FreeDiscovery/FreeDiscovery


FreeDiscovery is an open source e-Discovery and information retrieval engine. It is based on the scikit-learn library and has two main components,

* **FreeDiscovery Engine** provides a REST API for information retrieval applications. It aims to benefit existing e-Discovery and information retrieval platforms with a focus on text categorization, semantic search, document clustering, duplicates detection and e-mail threading.
  
  See `freediscovery.io/doc/stable/engine <http://freediscovery.io/doc/stable/engine/>`_
* **FreeDiscovery Core** is a Python package that extends scikit-learn with additional information retrieval functionality.
  
  See `freediscovery.io/doc/stable/python <http://freediscovery.io/doc/stable/python/>`_


FreeDiscovery is released under the 3-clause BSD licence.

|logo2|     |logo3|


.. |logo2| image:: https://freediscovery.github.io/static/grossmanlabs-old-logo-small.gif
    :target: http://www.grossmanlabs.com/

.. |logo3| image:: https://freediscovery.github.io/static/1D_logo_stacked.png
    :target: https://www.onediscovery.com/
